@@ -5,7 +5,13 @@ set_to_latex <- function(S, attributes) {
   if (length(idx) > 0) {
 
     A <- S[idx]
-    att <- attributes[idx]
+    decimal_places <- fcaR_options("decimal_places")
+    A <- A %>%
+      formatC(digits = decimal_places) %>%
+      stringr::str_replace_all("\\s*", "")
+
+    att <- attributes[idx] %>%
+      format_label()
 
     tmp <- paste0("\\ensuremath{\\left\\{",
                   stringr::str_flatten(paste0("{^{", A, "}}\\!/\\mathrm{", att, "}"),
@@ -67,52 +73,25 @@ imp_to_latex <- function(imp_set, ncols = 1,
 
   format_cols <- ifelse(numbered, "rrcl", "rcl")
 
-  output <- c(paste0("\\begin{longtable*}{", stringr::str_flatten(rep(format_cols, ncols)), "}"), output, "\\end{longtable*}")
+  sz <- fcaR_options("latex_size")
+  if (sz != "normalsize") {
 
-  output <- paste(output, collapse = "\n")
+    size_prefix <- paste0("\\begingroup\\", sz)
+    size_suffix <- "\\endgroup\n"
 
-  # cat(output)
+  } else {
 
-  return(invisible(output))
-
-}
-
-old_concepts_to_latex <- function(concept_list,
-                              ncols = 1,
-                              align = TRUE,
-                              numbered = TRUE,
-                              numbers = seq_along(concept_list)) {
-
-  output <- c()
-
-  for (i in seq_along(concept_list)) {
-
-    prefix <- ifelse(numbered, paste0(numbers[i], ": &"), "")
-    output <- c(output,
-                paste0(prefix,
-                       "$\\left(\\,",
-                       concept_list[[i]]$get_extent()$to_latex(print = FALSE),
-                       ",\\right.$",
-                       ifelse(align, "&", "\\,"),
-                       "$\\left.",
-                       concept_list[[i]]$get_intent()$to_latex(print = FALSE),
-                       "\\,\\right)$"))
+    size_prefix <- size_suffix <- ""
 
   }
 
-  output <- matrix(output, ncol = ncols)
-
-  output <- sapply(seq(nrow(output)), function(r) {
-
-    paste0(stringr::str_flatten(output[r, ], collapse = " & "), "\\\\")
-
-  })
-
-  format_cols <- c(ifelse(numbered, "l", ""),
-                   ifelse(align, "ll", "l"))
-
-  output <- c(paste0("\\begin{longtable}{",
-                     stringr::str_flatten(rep(format_cols, ncols)), "}"), output, "\\end{longtable}")
+  output <- c(paste0(size_prefix,
+                     "\\begin{longtable*}{",
+                     stringr::str_flatten(rep(format_cols, ncols)),
+                     "}"),
+              output,
+              paste0("\\end{longtable*}",
+                     size_suffix))
 
   output <- paste(output, collapse = "\n")
 
@@ -164,8 +143,25 @@ concepts_to_latex <- function(extents, intents,
   format_cols <- c(ifelse(numbered, "l", ""),
                    ifelse(align, "ll", "l"))
 
-  output <- c(paste0("\\begin{longtable}{",
-                     stringr::str_flatten(rep(format_cols, ncols)), "}"), output, "\\end{longtable}")
+  sz <- fcaR_options("latex_size")
+  if (sz != "normalsize") {
+
+    size_prefix <- paste0("\\begingroup\\", sz)
+    size_suffix <- "\\endgroup\n"
+
+  } else {
+
+    size_prefix <- size_suffix <- ""
+
+  }
+
+  output <- c(paste0(size_prefix,
+                     "\\begin{longtable*}{",
+                     stringr::str_flatten(rep(format_cols, ncols)),
+                     "}"),
+              output,
+              "\\end{longtable*}",
+              size_suffix)
 
   output <- paste(output, collapse = "\n")
 
