@@ -1,7 +1,6 @@
-#' @importFrom Matrix Diagonal
 .reduce_transitivity <- function(M) {
 
-  D <- Diagonal(n = ncol(M))
+  D <- Matrix::Diagonal(n = ncol(M))
   adj <- M - D
   transitivity <- adj %*% adj
   transitivity@x[transitivity@x > 0] <- 1
