@@ -41,6 +41,7 @@ test_that("fcaR operates on implications", {
   fc$find_implications()
 
   # Cardinality
+  # TODO: Check that cardinality is an integer
   expect_is(fc$implications$cardinality(), "integer")
 
   # Rule size
@@ -58,6 +59,7 @@ test_that("fcaR operates on implications", {
 
   # At this moment, we're at a fixed point, but we could apply
   # some more rules if needed:
+  # TODO: Revisar Rsimplification con ejemplo planets
   expect_error(fc$implications$apply_rules(rules = equivalencesRegistry$get_entry_names(),
                                            reorder = TRUE,
                                            parallelize = FALSE), NA)
@@ -93,12 +95,64 @@ test_that("fcaR prints implications", {
 
 })
 
+test_that("fcaR checks if implications hold in a context", {
+
+  objects <- paste0("O", 1:6)
+  n_objects <- length(objects)
+
+  attributes <- paste0("P", 1:6)
+  n_attributes <- length(attributes)
+
+  I <- matrix(data = c(0, 1, 0.5, 0, 0, 0.5,
+                       1, 1, 0.5, 0, 0, 0,
+                       0.5, 1, 0, 0, 1, 0,
+                       0.5, 0, 0, 1, 0.5, 0,
+                       1, 0, 0, 0.5, 0, 0,
+                       0, 0, 1, 0, 0, 0),
+              nrow = n_objects,
+              byrow = FALSE)
+
+  colnames(I) <- attributes
+  rownames(I) <- objects
+
+  fc <- FormalContext$new(I = I)
+  fc$find_implications()
+  imps <- fc$implications$clone()
+  expect_true(all(imps %holds_in% fc))
+  expect_true(all(Matrix::as.matrix(fc %respects% imps)))
+
+})
+
+test_that("fcaR checks entailment and equivalence of implication sets", {
+
+  fc_planets <- FormalContext$new(planets)
+  fc_planets$find_implications()
+  # imps is the basis
+  imps <- fc_planets$implications$clone()
+  imps2 <- imps$clone()
+  # imps2 is an equivalent set of implications
+  # where we have removed redundancies
+  imps2$apply_rules(c("simp"))
+  # Any implication in imps2 follows from imps
+  expect_true(all(imps %entails% imps2))
+  # And viceversa
+  expect_true(all(imps2 %entails% imps))
+
+  # Equivalence of implication sets
+  expect_true(imps %~% imps2)
+  # If we remove any implication from imps2,
+  # they will not be equivalent
+  expect_false(imps %~% imps2[1:9])
+
+})
+
 test_that("fcaR adds and appends implications", {
 
   skip_if_not_installed("arules")
 
   fc <- FormalContext$new(I = Mushroom)
 
+  # TODO: Falla cuando se añaden implicaciones a algo vacío
   fc$implications$add(mush_clean)
 
   fc$implications$add(fc$implications)
@@ -262,13 +316,13 @@ test_that("fcaR computes closure wrt implications", {
   fc$implications$add(mush_clean)
 
   # A fuzzy set
-  A <- SparseSet$new(attributes = fc$attributes)
+  A <- Set$new(attributes = fc$attributes)
   A$assign(attributes = "CapColor=white", values = 1)
 
   # Compute the closure
   expect_error(cl <- fc$implications$closure(A, reduce = TRUE, verbose = TRUE), NA)
   # Associated attributes
-  expect_is(cl$closure, "SparseSet")
+  expect_is(cl$closure, "Set")
 
   expect_is(cl$implications, "ImplicationSet")
 
@@ -304,6 +358,13 @@ test_that("fcaR simplifies implications", {
 
   expect_is(L, "list")
 
+  L <- Rsimplification(LHS = fc$implications$get_LHS_matrix(),
+                          RHS = fc$implications$get_RHS_matrix(),
+                          attributes = fc$attributes)
+
+  expect_is(L, "list")
+
+
 })
 
 test_that("fcaR makes a recommendation", {
@@ -330,7 +391,7 @@ test_that("fcaR makes a recommendation", {
   fc$find_implications()
 
   # A fuzzy set
-  S <- SparseSet$new(attributes = fc$attributes)
+  S <- Set$new(attributes = fc$attributes)
   S$assign(P1 = 1)
 
   expect_error(fc$implications$recommend(S = S, attribute_filter = fc$attributes[1]), NA)
@@ -360,6 +421,7 @@ test_that("fcaR filters and removes implications", {
   fc <- FormalContext$new(I = I)
   fc$find_implications()
 
+  # TODO: FALLA el filtrado
   expect_error(fc$implications$filter(lhs = fc$attributes[1], rhs = fc$attributes[1:2]), NA)
 
   expect_warning(fc$implications$filter(lhs = fc$attributes[6], rhs = fc$attributes[3]))
@@ -406,11 +468,11 @@ test_that("fcaR adds implications from scratch", {
 
   expect_output(print(fc$implications))
 
-  lhs1 <- SparseSet$new(attributes = fc$attributes)
+  lhs1 <- Set$new(attributes = fc$attributes)
   lhs1$assign(attributes = fc$attributes[1],
               values = 1)
 
-  rhs1 <- SparseSet$new(attributes = fc$attributes)
+  rhs1 <- Set$new(attributes = fc$attributes)
   rhs1$assign(fc$attributes[c(2,4)],
               values = c(1, 1))
 
@@ -443,11 +505,11 @@ test_that("fcaR can use generalization", {
   fc$implications <- ImplicationSet$new(attributes = fc$attributes)
   expect_equal(fc$implications$cardinality(), 0)
 
-  lhs1 <- SparseSet$new(attributes = fc$attributes)
+  lhs1 <- Set$new(attributes = fc$attributes)
   lhs1$assign(attributes = fc$attributes[1],
               values = 1)
 
-  rhs1 <- SparseSet$new(attributes = fc$attributes)
+  rhs1 <- Set$new(attributes = fc$attributes)
   rhs1$assign(fc$attributes[c(2,4)],
               values = c(1, 1))
 
@@ -455,11 +517,11 @@ test_that("fcaR can use generalization", {
 
   expect_error(fc$implications$apply_rules("composition"), NA)
 
-  lhs2 <- SparseSet$new(attributes = fc$attributes)
+  lhs2 <- Set$new(attributes = fc$attributes)
   lhs2$assign(attributes = fc$attributes[c(1, 3)],
               values = c(1, 1))
 
-  rhs2 <- SparseSet$new(attributes = fc$attributes)
+  rhs2 <- Set$new(attributes = fc$attributes)
   rhs2$assign(fc$attributes[4],
               values = 1)
 
@@ -494,11 +556,11 @@ test_that("fcaR filters implications", {
   fc$implications <- ImplicationSet$new(attributes = fc$attributes)
   expect_equal(fc$implications$cardinality(), 0)
 
-  lhs1 <- SparseSet$new(attributes = fc$attributes)
+  lhs1 <- Set$new(attributes = fc$attributes)
   lhs1$assign(attributes = fc$attributes[1],
               values = 1)
 
-  rhs1 <- SparseSet$new(attributes = fc$attributes)
+  rhs1 <- Set$new(attributes = fc$attributes)
   rhs1$assign(fc$attributes[c(2,4)],
               values = c(1, 1))
 
@@ -532,6 +594,7 @@ test_that("fcaR subsets implications", {
   fc$find_implications()
 
   expect_error(fc$implications[fc$implications$support() > 0.1], NA)
+  # TODO: FALLA
   expect_error(fc$implications[-c(1:2)], NA)
   expect_error(fc$implications[c(-1, 2)])
   expect_error(fc$implications[0], NA)
@@ -566,3 +629,41 @@ test_that("fcaR computes the canonical basis from an ImplicationSet", {
   expect_is(imps, "ImplicationSet")
 
 })
+
+test_that(desc = "fcaR can use equivalence rules", {
+
+  expect_error(rules <- equivalencesRegistry$get_entry_names(),
+               NA)
+
+  for (r in rules) {
+
+    objects <- paste0("O", 1:6)
+    n_objects <- length(objects)
+
+    attributes <- paste0("P", 1:6)
+    n_attributes <- length(attributes)
+
+    I <- matrix(data = c(0, 1, 0.5, 0, 0, 0.5,
+                         1, 1, 0.5, 0, 0, 0,
+                         0.5, 1, 0, 0, 1, 0,
+                         0.5, 0, 0, 1, 0.5, 0,
+                         1, 0, 0, 0.5, 0, 0,
+                         0, 0, 1, 0, 0, 0),
+                nrow = n_objects,
+                byrow = FALSE)
+
+    colnames(I) <- attributes
+    rownames(I) <- objects
+
+    fc <- FormalContext$new(I = I)
+    fc$find_implications()
+
+    cat("Testing", r, "\n")
+
+    expect_error(fc$implications$apply_rules(r,
+                                             parallelize = FALSE),
+                 NA)
+
+  }
+
+})
